@@ -1,13 +1,13 @@
 """This module implements the generation of connector configuration files."""
 
+import json
 from pathlib import Path
 from typing import Any, Dict, Optional, Union
 from urllib.parse import parse_qs, urlparse
 
-import requests
-from dataprep.connector.schema.base import BaseDef
-
 from ..schema import AuthorizationDef, ConfigDef, PaginationDef
+from ..schema.base import BaseDef
+from ..utils import Request
 from .state import ConfigState
 from .table import gen_schema_from_path, search_table_path
 
@@ -129,18 +129,12 @@ class ConfigGenerator:
 
 
 def _create_config(req: Dict[str, Any], table_path: Optional[str] = None) -> ConfigDef:
-    resp = requests.request(
-        req["method"].lower(),
-        req["url"],
-        params=req["params"],
-        headers=req["headers"],
-    )
+    requests = Request(req["url"])
+    resp = requests.post(_data=req["params"], _headers=req["headers"])
 
-    if resp.status_code != 200:
-        raise RuntimeError(
-            f"Request to HTTP endpoint not successful: {resp.status_code}: {resp.text}"
-        )
-    payload = resp.json()
+    if resp.status != 200:
+        raise RuntimeError(f"Request to HTTP endpoint not successful: {resp.status}: {resp.reason}")
+    payload = json.loads(resp.read())
 
     if table_path is None:
         table_path = search_table_path(payload)
