@@ -385,12 +385,15 @@ def render_crossfilter(
         all_cols = itmdt["all_cols"]
     else:
         all_cols = itmdt["num_cols"]
-
     scatter_df = itmdt["scatter_source"]
     # all other plots except for scatter plot, used for cat-cat and cat-num interactions.
     other_plots = itmdt["other_plots"]
-    scatter_df["__x__"] = scatter_df[scatter_df.columns[0]]
-    scatter_df["__y__"] = scatter_df[scatter_df.columns[0]]
+    if scatter_df.empty:
+        scatter_df["__x__"] = [None] * len(itmdt["scatter_source"])
+        scatter_df["__y__"] = [None] * len(itmdt["scatter_source"])
+    else:
+        scatter_df["__x__"] = scatter_df[scatter_df.columns[0]]
+        scatter_df["__y__"] = scatter_df[scatter_df.columns[0]]
     source_scatter = ColumnDataSource(scatter_df)
     source_xy_value = ColumnDataSource({"x": [scatter_df.columns[0]], "y": [scatter_df.columns[0]]})
     var_list = list(all_cols)
