@@ -1549,10 +1549,10 @@ def render_cat(itmdt: Intermediate, cfg: Config) -> Dict[str, Any]:
     # pylint: disable=too-many-locals,too-many-branches
 
     if cfg.plot.report:
-        plot_width = 450
-        plot_height = 400
-        plot_width_bar = 280
-        plot_height_bar = 248
+        plot_width = 400
+        plot_height = 350
+        plot_width_bar = plot_width
+        plot_height_bar = plot_height
     else:
         plot_width = cfg.plot.width if cfg.plot.width is not None else 450
         plot_height = cfg.plot.height if cfg.plot.height is not None else 400
@@ -1866,10 +1866,10 @@ def render_num(itmdt: Intermediate, cfg: Config) -> Dict[str, Any]:
     """
     # pylint: disable=too-many-locals
     if cfg.plot.report:
-        plot_width = 450
-        plot_height = 400
-        plot_width_hist = 280
-        plot_height_hist = 248
+        plot_width = 400
+        plot_height = 350
+        plot_width_hist = plot_width
+        plot_height_hist = plot_height
     else:
         plot_width = cfg.plot.width if cfg.plot.width is not None else 450
         plot_height = cfg.plot.height if cfg.plot.height is not None else 400
@@ -2302,10 +2302,18 @@ def parse_grps(
 
     x_lrgst = xgrps.nlargest(ngroups)
     df = df[df[x].isin(x_lrgst.index)]
-    stats = {f"{x}_ttl": len(xgrps), f"{x}_shw": len(x_lrgst)}
     y_lrgst = ygrps.nlargest(nsubgroups)
     df = df[df[y].isin(y_lrgst.index)]
-    stats.update(zip((f"{y}_ttl", f"{y}_shw"), (len(ygrps), len(y_lrgst))))
+    stats = {
+        f"{x}_ttl": len(xgrps),
+        f"{x}_shw": len(x_lrgst),
+        f"{y}_ttl": len(ygrps),
+        f"{y}_shw": len(y_lrgst),
+    }
+    if df.empty:
+        size = min(len(x_lrgst), len(y_lrgst))
+        df = pd.DataFrame({x: x_lrgst[:size], y: y_lrgst[:size]})
+        df["cnt"] = 0
     df[[x, y]] = df[[x, y]].astype(str)
     # final format
     df = df.pivot_table(index=y, columns=x, values="cnt", fill_value=0, aggfunc="sum")
