@@ -105,3 +105,9 @@ def test_dataset() -> None:
 
 def test_random_df(random_df: pd.DataFrame) -> None:
     create_report(random_df)
+
+
+def test_cat_df() -> None:
+    df = load_dataset("titanic")
+    ddf = df[["Name", "Sex"]]
+    create_report(ddf)
